==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebTabGroupPaneDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebTabGroupPaneDescription } from "./WebTabGroupPaneDescription";
/**
 * @hidden
 */
export let WebTabGroupPaneDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabGroupPaneDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabGroupPaneDescriptionMetadata.a == null) {
                WebTabGroupPaneDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabGroupPaneDescriptionMetadata.c(WebTabGroupPaneDescriptionMetadata.a);
            }
            if (a.k(WebTabGroupPaneDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebTabGroupPaneDescriptionMetadata.a);
        }
        static c(a) {
            WebDockManagerPaneDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:TabGroupPane");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__skipSuffix", "Boolean");
            a.item("Id", "String");
            a.item("PaneType", "(wc:Type)ExportedType:string:DockManagerPaneType");
            a.item("PaneType@names", "SplitPane;ContentPane;TabGroupPane;DocumentHost");
            a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
            a.item("Size", "Number:double");
            a.item("SelectedIndex", "Number:double");
            a.item("AllowEmpty", "Boolean");
            WebTabGroupPaneDescriptionMetadata.e(a);
        }
        static d(a) {
            WebTabGroupPaneDescriptionMetadata.b(a);
            a.ac("WebTabGroupPane", () => new WebTabGroupPaneDescription());
            a.ab("WebTabGroupPane", WebTabGroupPaneDescriptionMetadata.a);
        }
        static e(a) {
            a.item("__preferUnsuffixed", "Boolean");
        }
    }
    WebTabGroupPaneDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTabGroupPaneDescriptionMetadata, 'WebTabGroupPaneDescriptionMetadata');
    WebTabGroupPaneDescriptionMetadata.a = null;
    return WebTabGroupPaneDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebTabGroupPaneDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebTabGroupPaneDescription } from "./WebTabGroupPaneDescription";
/**
 * @hidden
 */
export let WebTabGroupPaneDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabGroupPaneDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabGroupPaneDescriptionMetadata.a == null) {
                WebTabGroupPaneDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabGroupPaneDescriptionMetadata.c(WebTabGroupPaneDescriptionMetadata.a);
            }
            if (a.k(WebTabGroupPaneDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebTabGroupPaneDescriptionMetadata.a);
        }
        static c(a) {
            WebDockManagerPaneDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:TabGroupPane");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Id", "String");
            a.item("PaneType", "(wc:Type)ExportedType:string:DockManagerPaneType");
            a.item("PaneType@names", "SplitPane;ContentPane;TabGroupPane;DocumentHost");
            a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
            a.item("Size", "Number:double");
            a.item("SelectedIndex", "Number:double");
            a.item("AllowEmpty", "Boolean");
            a.item("IsMaximized", "Boolean");
            WebTabGroupPaneDescriptionMetadata.e(a);
        }
        static d(a) {
            WebTabGroupPaneDescriptionMetadata.b(a);
            a.ae("WebTabGroupPane", () => new WebTabGroupPaneDescription());
            a.ad("WebTabGroupPane", WebTabGroupPaneDescriptionMetadata.a);
        }
        static e(a) {
            a.item("__preferUnsuffixed", "Boolean");
        }
    }
    WebTabGroupPaneDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTabGroupPaneDescriptionMetadata, 'WebTabGroupPaneDescriptionMetadata');
    WebTabGroupPaneDescriptionMetadata.a = null;
    return WebTabGroupPaneDescriptionMetadata;
})();
